# Redmine - project management software
# Copyright (C) 2006-2012  Jean-Philippe Lang
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.

module Redmine
  module Views
    module Builders
      def self.for(format, request, response, &block)
        builder = case format
          when 'xml',  :xml;  Builders::Xml.new(request, response)
          when 'json', :json; Builders::Json.new(request, response)
          else; raise "No builder for format #{format}"
        end
        if block
          block.call(builder)
        else
          builder
        end
      end
    end
  end
end
